=====================
Appendix A. Changelog
=====================

v1.0.0
------

* RENAME TO *Coil CMS*
* User documentation
* Form validation
* Redis for storing data
* Rebuilding the site, using RQ as a task queue

v0.6.0
------

* Permission management
* ``setup.py`` and Python packaging
* ``comet`` management command
* more modern pages
* multiple issues fixed

v0.5.0
------

* Switch to Flask
* Cookie-based authentication
* User management
* Style wysihtml properly
* Rename to *Comet CMS*

v0.0.1
------

* Initial version
* Called ``nikola webapp``
* using bottle
* HTTP Basic “Authentication” (sorry)
* wysihtml
